@@ -8,32 +8,36 @@ register = template.Library()
 
 @register.simple_tag(takes_context=True)
 def querystring(context, **kwargs):
-    args = context['request'].GET.copy()
+    args = context["request"].GET.copy()
     for k, v in kwargs.items():
         args[k] = v
     return args.urlencode()
 
 
-SORT_FIELD = getattr(settings, 'SORT_FIELD', 'o')
+SORT_FIELD = getattr(settings, "SORT_FIELD", "o")
 
-SORT_FIELD = getattr(settings, 'SORT_FIELD', 'o')
+SORT_FIELD = getattr(settings, "SORT_FIELD", "o")
 
 
-SORT_ICON = getattr(settings, 'SORT_ICON', '<i class="fa fa-sort"></i>')
-SORT_ASC_ICON = getattr(settings, 'SORT_ASC_ICON', '<i class="fa fa-sort-amount-asc"></i>')
-SORT_DESC_ICON = getattr(settings, 'SORT_DESC_ICON', '<i class="fa fa-sort-amount-desc"></i>')
+SORT_ICON = getattr(settings, "SORT_ICON", '<i class="fa fa-sort"></i>')
+SORT_ASC_ICON = getattr(
+    settings, "SORT_ASC_ICON", '<i class="fa fa-sort-amount-asc"></i>'
+)
+SORT_DESC_ICON = getattr(
+    settings, "SORT_DESC_ICON", '<i class="fa fa-sort-amount-desc"></i>'
+)
 
 SORTANCHOR_TEMPLATE = '<a href="%(url)s">%(text)s</a>'
 
-CRISPY_TEMPLATE_PACK = getattr(settings, 'CRISPY_TEMPLATE_PACK')
-if CRISPY_TEMPLATE_PACK == 'bootstrap4':
-    SORTANCHOR_TEMPLATE = '<a class="text-decoration-none" href="%(url)s">%(text)s <small>%(icon)s</small></a>'
+CRISPY_TEMPLATE_PACK = getattr(settings, "CRISPY_TEMPLATE_PACK")
+if CRISPY_TEMPLATE_PACK == "bootstrap4":
+    SORTANCHOR_TEMPLATE = '<a class="text-nowrap text-decoration-none" href="%(url)s">%(text)s <small>%(icon)s</small></a>'
 
-if CRISPY_TEMPLATE_PACK == 'bootstrap5':
-    SORTANCHOR_TEMPLATE = '<a class="text-decoration-none" href="%(url)s">%(text)s <small>%(icon)s</small></a>'
+if CRISPY_TEMPLATE_PACK == "bootstrap5":
+    SORTANCHOR_TEMPLATE = '<a class="text-nowrap text-decoration-none" href="%(url)s">%(text)s <small>%(icon)s</small></a>'
 
 
-SORTANCHOR_TEMPLATE = getattr(settings, 'SORANCHOR_TEMPLATE', SORTANCHOR_TEMPLATE)
+SORTANCHOR_TEMPLATE = getattr(settings, "SORANCHOR_TEMPLATE", SORTANCHOR_TEMPLATE)
 
 
 def sortanchor(parser, token):
@@ -44,8 +48,7 @@ def sortanchor(parser, token):
     """
     bits = [b for b in token.split_contents()]
     if len(bits) < 2:
-        raise template.TemplateSyntaxError(
-                        "anchor tag takes at least 1 argument.")
+        raise template.TemplateSyntaxError("anchor tag takes at least 1 argument.")
 
     try:
         title = bits[2]
@@ -72,6 +75,7 @@ class SortAnchorNode(template.Node):
         <a href="/the/current/path/?sort=name" title="Name">Name</a>
 
     """
+
     def __init__(self, field, title, is_default):
         self.field = field
         self.title = title
@@ -86,19 +90,19 @@ class SortAnchorNode(template.Node):
                 title = title[1:-1]
             else:
                 raise template.TemplateSyntaxError(
-                        'sortanchor tag title '
-                        'must be a "string", _("trans string"), or variable'
-                        )
+                    "sortanchor tag title "
+                    'must be a "string", _("trans string"), or variable'
+                )
         elif title.startswith('_("') or title.startswith("_('"):
             title = _(title[3:-2])
         else:
             #  Title is var
             title = context[title]
 
-        request = context['request']
+        request = context["request"]
         getvars = request.GET.copy()
 
-        currentsort = ''
+        currentsort = ""
         sortby = self.field
         icon = SORT_ICON
 
@@ -115,7 +119,7 @@ class SortAnchorNode(template.Node):
             currentsort = getvars[SORT_FIELD]
         else:
             if self.is_default:
-                if self.is_default == '-':
+                if self.is_default == "-":
                     currentsort = invert_order(self.field)
                 else:
                     currentsort = self.field
@@ -129,7 +133,7 @@ class SortAnchorNode(template.Node):
 
         getvars[SORT_FIELD] = sortby
 
-        url = '%s?%s' % (request.path, getvars.urlencode())
+        url = "%s?%s" % (request.path, getvars.urlencode())
         return SORTANCHOR_TEMPLATE % {"url": url, "text": title, "icon": icon}
 
 
